function figures1d

strFigName = 'figures1d';

load(strFigName);

fOSIThresh = 0.3;

vbIncludePair = all(mfOSIPairsAll > fOSIThresh, 2);

hFig = figure;
plot(vfGratCorrsAll, vfMovieCorrsAll, '.', 'MarkerSize', 12, 'MarkerFaceColor', [0.5 0.5 0.5], 'MarkerEdgeColor', [0.5 0.5 0.5]);
hold on;
plot(vfGratCorrsAll(vbIncludePair), vfMovieCorrsAll(vbIncludePair), 'k.', 'MarkerSize', 16);
set(gca, 'FontSize', 48, 'LineWidth', 2, 'XTick', [-1 0 1], 'YTick', [-1 0 1]);
axis([-1.1 1.1 -1.1 1.1]);
axis square;
xlabel('Grating corr. (\rho_g)');
ylabel('Movie corr. (\rho_m)');

[b, ~, ~, ~, stats] = regress(vfMovieCorrsAll(vbIncludePair), [ vfGratCorrsAll(vbIncludePair) ones(nnz(vbIncludePair), 1)]);
fprintf('Regression: pair-wise grating corr. vs pair-wise movie corr.\n');
fprintf('   R^2 (OSI>0.3): %.4f, p: %.4f\n', stats(1), stats(3));

hLine = refline(b);
set(hLine, 'Color', 'k', 'LineWidth', 4, 'LineStyle', '--');
text(-1, 1, sprintf('R^2 = %.2f', stats(1)), 'FontSize', 48);

[~, ~, ~, ~, stats] = regress(vfMovieCorrsAll, [vfGratCorrsAll ones(numel(vbIncludePair), 1)]);
fprintf('   R^2 (all): %.4f, p: %.4f\n', stats(1), stats(3));

hgsave(hFig, [strFigName '.fig']);
if exist('export_fig', 'file')
   export_fig(hFig, strFigName, '-pdf');
end